@@ -1,7 +1,7 @@
 import time
 import threading
-from debugging import *
-from omnitools import list_or_dict, p
+import sys
+from omnitools import p, debug_info
 
 
 __ALL__ = ["Threadswrapper", "args"]
@@ -14,34 +14,35 @@ class ThreadWrapper:
         self.sema = semaphore
         self.debug_time = False
 
-    def __run_job(self, job: Callable[[], Any], result: list_or_dict = None,
-                  key: Any = None) -> None:
-        self.sema.acquire()
+    def __run_job(self, job, result = None, key = None) -> None:
+        response = None
         try:
+            self.sema.acquire()
             start_time = time.time()
             self.total_thread_count += 1
+            response = job()
             if isinstance(result, list):
-                result.append(job())
+                result.append(response)
             elif isinstance(result, dict):
-                result[key] = job()
+                result[key] = response
             duration = time.time()-start_time
             if self.debug_time:
                 count = str(self.total_thread_count).ljust(20)
                 qualname = job.__qualname__.ljust(50)
                 timestamp = str(int(time.time() * 1000) / 1000).ljust(20)[6:]
-                s = f"Thread {count}{qualname}{timestamp}{duration}s\n"
+                s = "Thread {}{}{}{}s\n".format(count, qualname, timestamp, duration)
                 if duration >= 0.5:
                     sys.stderr.write(s)
                     sys.stderr.flush()
                 else:
                     p(s)
         except:
-            p(debug_info()[0])
+            response = debug_info()[0]
         finally:
             self.sema.release()
+            return response
 
-    def add(self, job: Callable[[], Any], result: list_or_dict = None,
-            key: Any = None) -> bool:
+    def add(self, job, result = None, key = None) -> bool:
         if result is None:
             result = {}
         if key is None:
